@@ -13,17 +13,19 @@ var searchData=
   ['solverbase_3c_20factorization_3a_3afactorization_3c_20valuetype_2c_20indextype_20_3e_20_3e_10',['SolverBase&lt; factorization::Factorization&lt; ValueType, IndexType &gt; &gt;',['../classgko_1_1solver_1_1SolverBase.html',1,'gko::solver']]],
   ['solverbase_3c_20linop_20_3e_11',['SolverBase&lt; LinOp &gt;',['../classgko_1_1solver_1_1SolverBase.html',1,'gko::solver']]],
   ['solverbase_3c_20matrix_3a_3acsr_3c_20default_5fprecision_2c_20int32_20_3e_20_3e_12',['SolverBase&lt; matrix::Csr&lt; default_precision, int32 &gt; &gt;',['../classgko_1_1solver_1_1SolverBase.html',1,'gko::solver']]],
-  ['span_13',['span',['../structgko_1_1span.html',1,'gko']]],
-  ['sparselib_14',['sparselib',['../classgko_1_1matrix_1_1Csr_1_1sparselib.html',1,'gko::matrix::Csr']]],
-  ['sparsitycsr_15',['SparsityCsr',['../classgko_1_1matrix_1_1SparsityCsr.html',1,'gko::matrix']]],
-  ['squared_5fnorm_5foperation_16',['squared_norm_operation',['../structgko_1_1accessor_1_1squared__norm__operation.html',1,'gko::accessor']]],
-  ['squared_5fnorm_5foperaton_17',['squared_norm_operaton',['../structgko_1_1accessor_1_1squared__norm__operaton.html',1,'gko::accessor']]],
-  ['status_18',['status',['../structgko_1_1experimental_1_1mpi_1_1status.html',1,'gko::experimental::mpi']]],
-  ['stopping_5fstatus_19',['stopping_status',['../classgko_1_1stopping__status.html',1,'gko']]],
-  ['strategy_5ftype_20',['strategy_type',['../classgko_1_1matrix_1_1Csr_1_1strategy__type.html',1,'gko::matrix::Csr&lt; ValueType, IndexType &gt;::strategy_type'],['../classgko_1_1matrix_1_1Hybrid_1_1strategy__type.html',1,'gko::matrix::Hybrid&lt; ValueType, IndexType &gt;::strategy_type']]],
-  ['stream_21',['Stream',['../classgko_1_1log_1_1Stream.html',1,'gko::log']]],
-  ['streamerror_22',['StreamError',['../classgko_1_1StreamError.html',1,'gko']]],
-  ['sub_23',['sub',['../structgko_1_1accessor_1_1sub.html',1,'gko::accessor']]],
-  ['summary_5fentry_24',['summary_entry',['../structgko_1_1log_1_1ProfilerHook_1_1summary__entry.html',1,'gko::log::ProfilerHook']]],
-  ['summarywriter_25',['SummaryWriter',['../classgko_1_1log_1_1ProfilerHook_1_1SummaryWriter.html',1,'gko::log::ProfilerHook']]]
+  ['solverprogress_13',['SolverProgress',['../classgko_1_1log_1_1SolverProgress.html',1,'gko::log']]],
+  ['sor_14',['Sor',['../classgko_1_1preconditioner_1_1Sor.html',1,'gko::preconditioner']]],
+  ['span_15',['span',['../structgko_1_1span.html',1,'gko']]],
+  ['sparselib_16',['sparselib',['../classgko_1_1matrix_1_1Csr_1_1sparselib.html',1,'gko::matrix::Csr']]],
+  ['sparsitycsr_17',['SparsityCsr',['../classgko_1_1matrix_1_1SparsityCsr.html',1,'gko::matrix']]],
+  ['squared_5fnorm_5foperation_18',['squared_norm_operation',['../structgko_1_1accessor_1_1squared__norm__operation.html',1,'gko::accessor']]],
+  ['squared_5fnorm_5foperaton_19',['squared_norm_operaton',['../structgko_1_1accessor_1_1squared__norm__operaton.html',1,'gko::accessor']]],
+  ['status_20',['status',['../structgko_1_1experimental_1_1mpi_1_1status.html',1,'gko::experimental::mpi']]],
+  ['stopping_5fstatus_21',['stopping_status',['../classgko_1_1stopping__status.html',1,'gko']]],
+  ['strategy_5ftype_22',['strategy_type',['../classgko_1_1matrix_1_1Csr_1_1strategy__type.html',1,'gko::matrix::Csr&lt; ValueType, IndexType &gt;::strategy_type'],['../classgko_1_1matrix_1_1Hybrid_1_1strategy__type.html',1,'gko::matrix::Hybrid&lt; ValueType, IndexType &gt;::strategy_type']]],
+  ['stream_23',['Stream',['../classgko_1_1log_1_1Stream.html',1,'gko::log']]],
+  ['streamerror_24',['StreamError',['../classgko_1_1StreamError.html',1,'gko']]],
+  ['sub_25',['sub',['../structgko_1_1accessor_1_1sub.html',1,'gko::accessor']]],
+  ['summary_5fentry_26',['summary_entry',['../structgko_1_1log_1_1ProfilerHook_1_1summary__entry.html',1,'gko::log::ProfilerHook']]],
+  ['summarywriter_27',['SummaryWriter',['../classgko_1_1log_1_1ProfilerHook_1_1SummaryWriter.html',1,'gko::log::ProfilerHook']]]
 ];
